@@ -138,7 +138,7 @@ CCF <- function(.data, ..., lag_max = NULL, type = c("correlation", "covariance"
     ccf <- ccf(x = eval_tidy(value1, data = .data),
                y = eval_tidy(value2, data = .data),
                plot=FALSE, ...)
-    lag <- as.numeric(ccf$lag)*frequency(.data)
+    lag <- as.numeric(ccf$lag)
     tibble(lag = lag, ccf = as.numeric(ccf$acf))
   }
   value <- enexprs(...)
@@ -267,6 +267,9 @@ vec_cast.cf_lag.double <- function(x, to, ...) vec_data(x)
 #' @method vec_cast.double cf_lag
 #' @export
 vec_cast.double.cf_lag <- function(x, to, ...) vec_data(x)
+#' @method vec_cast.character cf_lag
+#' @export
+vec_cast.character.cf_lag <- function(x, to, ...) format(x)
 
 #' @export
 index_valid.cf_lag <- function(x) TRUE
